<!DOCTYPE TS><TS>
<context>
    <name>AudioControl</name>
    <message>
        <source>Audio Properties</source>
        <translation>Propriétés Audio</translation>
    </message>
    <message>
        <source>OSS Device Mode</source>
        <translation>Mode du périphérique OSS</translation>
    </message>
    <message>
        <source>ReadWrite</source>
        <translation>LectureEcriture</translation>
    </message>
    <message>
        <source>ReadOnly / WriteOnly</source>
        <translation>LectureSeule / EcritureSeule</translation>
    </message>
    <message>
        <source>Device for WriteOnly or ReadWrite:</source>
        <translation>Périphérique en EcritureSeule ou EcritureLecture:</translation>
    </message>
    <message>
        <source>Device for ReadOnly:</source>
        <translation>Périphérique en LectureSeule:</translation>
    </message>
    <message>
        <source>Preferred Codec</source>
        <translation>Codec Préféré </translation>
    </message>
    <message>
        <source>G711u</source>
        <translation>G711u</translation>
    </message>
    <message>
        <source>GSM</source>
        <translation>GSM</translation>
    </message>
    <message>
        <source>iLBC</source>
        <translation>iLBC</translation>
    </message>
    <message>
        <source>Size of Payload</source>
        <translation>Taille de Payload</translation>
    </message>
    <message>
        <source>80 (échantillon 10 ms)</source>
        <translation></translation>
    </message>
    <message>
        <source>160 (échantillon 20 ms)</source>
        <translation></translation>
    </message>
    <message>
        <source>Ringing tone  (system bell)</source>
        <translation>Sonnerie (système)</translation>
    </message>
    <message>
        <source>Don&apos;t use ringing tone</source>
        <translation>Ne pas utiliser la sonnerie</translation>
    </message>
    <message>
        <source>Use ringing tone</source>
        <translation>Utiliser la sonnerie</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>bouton ok</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>bouton annuler</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>CallAudio</name>
    <message>
        <source>CallAudio: SendToRemote called but we don&apos;t have a valid session description yet</source>
        <translation>CallAudio: SendToRemote appelée mais actuellement aucun descripteur de session valide</translation>
    </message>
    <message>
        <source>CallAudio: Remote is currently putting us on hold, waiting patiently</source>
        <translation>CallAudio: mise en attente par le correspondant</translation>
    </message>
    <message>
        <source>CallAudio: Sending to remote site %s:%d</source>
        <translation>CallAudio: Envoi vers le correspondant distant %s:%d</translation>
    </message>
    <message>
        <source>CallAudio: OSS device already open (readwrite)</source>
        <translation>CallAudio: Périphérique OSS déjà ouvert (LectureEcriture)</translation>
    </message>
    <message>
        <source>** audioIn: openDevice Failed.</source>
        <translation>** audioIn: echec openDevice.</translation>
    </message>
    <message>
        <source>CallAudio: Opening OSS device %s for Input</source>
        <translation>CallAudio: Ouverture du périphérique OSS %s en entrée</translation>
    </message>
    <message>
        <source>CallAudio: Creating OSS-&gt;RTP Diverter</source>
        <translation>CallAudio: Création d'un OSS-&gt;RTP Diverter</translation>
    </message>
    <message>
        <source>CallAudio: Opening SW for video input and output</source>
        <translation>CallAudio: Ouverture de SW pour entrée/sortie vidéo</translation>
    </message>
    <message>
        <source>CallAudio: listening for incomming RTP</source>
        <translation>CallAudio: attente RTP entrant</translation>
    </message>
    <message>
        <source>CallAudio: Opening OSS device %s for Input and Output</source>
        <translation>CallAudio: Ouverture périphérique OSS %s en entrée/sortie</translation>
    </message>
    <message>
        <source>** audioOut: openDevice Failed.</source>
        <translation>** audioOut: echec openDevice.</translation>
    </message>
    <message>
        <source>CallAudio: Opening OSS device %s for Output</source>
        <translation>CallAudio: Ouverture périphérique OSS %s en sortie</translation>
    </message>
</context>
<context>
    <name>ContactParser</name>
    <message>
        <source>description</source>
        <translation>description</translation>
    </message>
    <message>
        <source>uri</source>
        <translation>uri</translation>
    </message>
    <message>
        <source>contact</source>
        <translation>contact</translation>
    </message>
</context>
<context>
    <name>ContactsListView</name>
    <message>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Contact</translation>
    </message>
</context>
<context>
    <name>DspAudioIn</name>
    <message>
        <source>DspAudioIn: Broken pipe</source>
        <translation>DspAudioIn: Broken pipe</translation>
    </message>
    <message>
        <source>DspAudioIn: UDP-failure(%d)</source>
        <translation>DspAudioIn: echec UDP(%d)</translation>
    </message>
</context>
<context>
    <name>DspAudioOut</name>
    <message>
        <source>DspAudio: Broken pipe</source>
        <translation>DspAudio: Broken pipe</translation>
    </message>
</context>
<context>
    <name>DspOutOss</name>
    <message>
        <source>Device Already Open</source>
        <translation>Périphérique déjà ouvert</translation>
    </message>
    <message>
        <source>Open Failed</source>
        <translation>Echec Ouverture</translation>
    </message>
    <message>
        <source>Format not supported</source>
        <translation>Format non supporté </translation>
    </message>
    <message>
        <source>Unsupported Number of Channels</source>
        <translation>Nombre de canals non supporté </translation>
    </message>
    <message>
        <source>WARNING: nonmonophonic driver, forced into stereo mode (experimental)</source>
        <translation>ATTENTION: pilote mono, force le mode stéréo (expérimental)</translation>
    </message>
    <message>
        <source>WARNING: driver rounded %d Hz request to %d Hz, off by %f%%</source>
        <translation>ATTENTION: le pilote a arrondi la requ&eacirc;te %d Hz vers %d Hz, de %f%%</translation>
    </message>
    <message>
        <source>Device Not Open</source>
        <translation>Périphérique Non Ouvert</translation>
    </message>
    <message>
        <source>warning: asked microphone for %d got %d</source>
        <translation>attention: %d demandé au micro, %d obtenu</translation>
    </message>
</context>
<context>
    <name>DspOutRtp</name>
    <message>
        <source>DspOutRtp:: Can&apos;t create socket</source>
        <translation>DspOutRtp:: création socket impossible</translation>
    </message>
    <message>
        <source>DspOutRtp::Hostname lookup failed</source>
        <translation>DspOutRtp:: échec recherche du nom</translation>
    </message>
    <message>
        <source>SipClient: Receiving message...</source>
        <translation>SipClient: réception message...</translation>
    </message>
    <message>
        <source>SipClient: STUN response for RTP</source>
        <translation>SipClient: réponse STUN pour RTP</translation>
    </message>
</context>
<context>
    <name>KCallTransfer</name>
    <message>
        <source>Transfer to URI:</source>
        <translation>Transféré vers l'URI:</translation>
    </message>
    <message>
        <source>help button</source>
        <translation>bouton aide</translation>
    </message>
    <message>
        <source>&amp;help...</source>
        <translation>&amp;aide...</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>bouton ok</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>bouton annuler</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>KCallWidget</name>
    <message>
        <source>Remote: </source>
        <translation>Correspondant: </translation>
    </message>
    <message>
        <source>  Remote:  </source>
        <translation>  Correspondant:  </translation>
    </message>
    <message>
        <source>Status: </source>
        <translation>Statut: </translation>
    </message>
    <message>
        <source>Audio: </source>
        <translation>Audio: </translation>
    </message>
    <message>
        <source>Dial</source>
        <translation>Composer</translation>
    </message>
    <message>
        <source>Hangup</source>
        <translation>Raccrocher</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Attente</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transfert</translation>
    </message>
    <message>
        <source>DTMF</source>
        <translation>DTMF</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Cacher</translation>
    </message>
    <message>
        <source>KCallWidget: Switching calls...</source>
        <translation>KCallWidget: échange des appels...</translation>
    </message>
    <message>
        <source>Call: </source>
        <translation>Appel: </translation>
    </message>
    <message>
        <source>Incoming Video Call: </source>
        <translation>Appel Vidéo Entrant: </translation>
    </message>
    <message>
        <source>Incoming Call: </source>
        <translation>Appel Entrant: </translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Répondre</translation>
    </message>
    <message>
        <source>Reject</source>
        <translation>Refuser</translation>
    </message>
    <message>
        <source>Outgoing Video Call: </source>
        <translation>Appel Vidéo Sortant: </translation>
    </message>
    <message>
        <source>Outgoing Call: </source>
        <translation>Appel Sortant: </translation>
    </message>
    <message>
        <source>Error: No Destination</source>
        <translation>Erreur: pas de destination</translation>
    </message>
    <message>
        <source>You must specify someone to call.</source>
        <translation>Vous devez indiquer un correspondant.</translation>
    </message>
    <message>
        <source>Close any program which might be using soundcard 
and then retry dial.</source>
        <translation>Fermez tous les programmes susceptibles d'utiliser la carte son
et réessayez d'appeler.</translation>
    </message>
    <message>
        <source>KCallAudio: Broken output pipe, disconnecting unpolitely</source>
        <translation>KCallAudio: Broken output pipe, déconnection intempestive</translation>
    </message>
    <message>
        <source>Unhold</source>
        <translation>Reprendre</translation>
    </message>
    <message>
        <source>KCallWidget: Handling redirect...</source>
        <translation>KCallWidget: gestion redirection...</translation>
    </message>
    <message>
        <source>Redirect</source>
        <translation>Redirection</translation>
    </message>
    <message>
        <source>Call redirected to: </source>
        <translation>Appel redirigé vers: </translation>
    </message>
    <message>
        <source>Do you want to proceed ? </source>
        <translation>Voulez vous continuer ? </translation>
    </message>
    <message>
        <source>KCallWidget: Starting force disconnect...</source>
        <translation>KCallWidget: Force la déconnexion...</translation>
    </message>
    <message>
        <source>Attached [holding]</source>
        <translation>Raccordé [en attente]</translation>
    </message>
    <message>
        <source>Attached [active]</source>
        <translation>Raccordé [actif]</translation>
    </message>
    <message>
        <source>Unattached</source>
        <translation>Non raccordé </translation>
    </message>
    <message>
        <source>Accept Call</source>
        <translation>Accepter l'appel</translation>
    </message>
    <message>
        <source>Close any program which might be using soundcard 
and then retry accepting call.</source>
        <translation>Fermer tous les programmes susceptibles d'utiliser la carte son
puis réessayez de répondre.</translation>
    </message>
    <message>
        <source>Accepted codec not found.</source>
        <translation>Codec pour la réception non trouvé.</translation>
    </message>
</context>
<context>
    <name>KInstantMessageWidget</name>
    <message>
        <source> Message - KPhone</source>
        <translation> Message - KPhone</translation>
    </message>
    <message>
        <source>Remote: </source>
        <translation>Correspondant: </translation>
    </message>
    <message>
        <source>  Remote:  </source>
        <translation>  Correspondant:  </translation>
    </message>
    <message>
        <source>Status: </source>
        <translation>Statut: </translation>
    </message>
    <message>
        <source>Message: </source>
        <translation>Message: </translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Cacher</translation>
    </message>
    <message>
        <source>Message received from </source>
        <translation>Message de </translation>
    </message>
    <message>
        <source>Error: No Destination</source>
        <translation>Erreur: pas de destinataire</translation>
    </message>
    <message>
        <source>You must specify someone to send message.</source>
        <translation>Vous devez indiquer le destinataire.</translation>
    </message>
    <message>
        <source>Message sent to </source>
        <translation>Message envoyé à </translation>
    </message>
</context>
<context>
    <name>KPhone</name>
    <message>
        <source>New Call...</source>
        <translation>Nouvel appel...</translation>
    </message>
    <message>
        <source>New Video Call...</source>
        <translation>Nouvel appel vidéo...</translation>
    </message>
    <message>
        <source>Identity...</source>
        <translation>Identité...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>SIP Preferences...</source>
        <translation>Préférences SIP...</translation>
    </message>
    <message>
        <source>Audio Preferences...</source>
        <translation>Préférences Audios...</translation>
    </message>
    <message>
        <source>Video Preferences...</source>
        <translation>Préférences Vidéos...</translation>
    </message>
    <message>
        <source>Phone Book</source>
        <translation>Annuaire</translation>
    </message>
    <message>
        <source>Tray Icon</source>
        <translation type="unfinished">Icone Plateau</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Préférences</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>About KPhone</source>
        <translation>À propos de KPhone</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>When starting KPhone for the first time, you should enter your identity information in the window appearing.
The information required for successful sipping are &apos;Full Name&apos;, &apos;User part of SIP URL&apos; and &apos;Host part of SIP URL&apos;.
Note for KPhone 3.xx users: copy &apos;~/.kde/share/config/kphonerc&apos; file to &apos;~/.qt&apos; directory.

If you have a NAPTR/SRV enabled DNS-server you can leave the &apos;Outbound Proxy&apos; and &apos;Authentication Username&apos; fields empty,
as KPhone will automatically search for the server information by the &apos;Host part of SIP URL&apos; and prompt the username/password.

Mark the auto register selection if you wish KPhone to automatically register your identity on application start.
If you want to use multiple identities, start KPhone with the &apos;-u&apos; option and the username of your selection.
For example:  &apos;kphone -u jsmith&apos;.

If you are behind a NAT (Network Address Translation) device, you should go to Preferences -&gt; SIP Preferences -&gt; Socket and
check the &apos;Use STUN Server&apos;

The right button of your mouse is your best friend in KPhone&apos;s main UI. By clicking the right mouse button (RMB) in the main
window you get a menu including all important functions of KPhone. You should edit the Phone Book and enter all your favourite
contacts there. Of course this is not mandatory but it increases your efficiency with KPhone.

When adding contacts to your Phone Book, simply click Add and enter the person&apos;s real name, SIP identity and the optional
description. If you want your contacts to be displayed in the main UI, just check the &apos;Add Identity ...&apos; box. After editing your
contacts you can return to the main UI by clicking Hide. All your selected contacts should now appear there. Making calls and 
sending instant messages to your contacts is easy with the RMB. Just click and select the function which you&apos;d like to initiate.
</source>
        <translation>Lorsque vous démarrez KPhone pour la première fois, vous devez utiliser la fenêtre qui apparaît pour indiquer votre identité.
Les informations nécessaires à l'utilisation du protocole SIP sont : &apos;Nom&apos;, &apos;Partie utilisateur de l'RL SIP&apos; et &apos;Partie hote de l'URL SIP&apos;.
Note pour les utilisateurs de KPhone 3.xx : copier le fichier &apos;~/.kde/share/config/kphonerc&apos; vers le répertoire &apos;~/.qt&apos;.

Si vous utilisez un serveur DNS NAPTR/SRV, vous pouvez laisser les champs &apos;Proxy Sortant&apos; et &apos;Authentification Utilisateur&apos; vides, car KPhone va automatiquement chercher l'information serveur grâce à la &apos;Partie hôte de l'URL SIP&apos; et demander le nom utilisateur/mot de passe.

Cocher la case &apos;Enregistrement auto&apos; si vous voulez que KPhone vous enregistre automatiquement lorsque l'application démarre.
Si vous voulez utiliser plusieurs identités, démarrez KPhone avec l'option &apos;-u&apos; en spécifiant le nom d'utilisateur désiré.
Par exemple:  &apos;kphone -u johnybigoude&apos;.

Si vous êtes sur un réseau NATé (translation d'adresse), vous devez sélectionner l'option &apos;Utiliser un serveur STUN&apos; dans Préférences -&gt; Préférences SIP -&gt; Socket.

Lors de l'utilisation de la fenêtre principale, le bouton droit de la souris vous permet d'accéder directement à un menu contenant toutes les fonctionnalités importantes de KPhone. Vous pouvez aussi utiliser l'annuaire pour stocker vos contacts. Cela n'est bien sûr pas obligatoire mais vous rendra plus efficace avec KPhone.

Pour entrer de nouveaux contacts dans l'annuaire, cliquer sur Ajouter et entrer le nom de la personne, son identité SIP et sa description (optionnel). Si vous voulez que vos contacts apparaissent dans la fenêtre principale, cocher la boîte &apos;Ajouter Identité...&apos;. Lorsque l'édition de vos contacts est terminée, vous pouvez retourner à la fenêtre principale en cliquant &apos;Cacher&apos; : tous les contacts sélectionnés devraient alors apparaître. Il est ensuite facile d'envoyer des messages instantanés ou d'appeler les contacts en utilisant le bouton droit de la souris : cliquez puis sélectionnez la fonction que vous voulez utiliser.
</translation>
    </message>
    <message>
        <source>is a &apos;Voice Over Internet&apos; phone</source>
        <translation>est un téléphone &apos;Voice Over Internet&apos;</translation>
    </message>
    <message>
        <source>Copyright (c) 2000 Billy Biggs</source>
        <translation>Copyright (c) 2000 Billy Biggs</translation>
    </message>
    <message>
        <source>Copyright (c) 2004 Wirlab</source>
        <translation>Copyright (c) 2004 Wirlab</translation>
    </message>
    <message>
        <source>KPhone is released under the GPL</source>
        <translation>KPhone est distribué sous licence GPL</translation>
    </message>
    <message>
        <source>For more information, see</source>
        <translation>Pour en savoir plus, consultez :</translation>
    </message>
</context>
<context>
    <name>KPhoneView</name>
    <message>
        <source>Set Identity</source>
        <translation>Entrer l'identité </translation>
    </message>
    <message>
        <source>Send Message</source>
        <translation>Envoyer Message</translation>
    </message>
    <message>
        <source>Call</source>
        <translation>Appeler</translation>
    </message>
    <message>
        <source>Video Call</source>
        <translation>Appel Vidéo</translation>
    </message>
    <message>
        <source>Phone Book</source>
        <translation>Annuaire</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>En Ligne</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Occupé </translation>
    </message>
    <message>
        <source>Be Right Back</source>
        <translation>De Retour Bientôt</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Absent</translation>
    </message>
    <message>
        <source>On The Phone</source>
        <translation>Au Téléphone</translation>
    </message>
    <message>
        <source>Out To Lunch</source>
        <translation>Parti Manger</translation>
    </message>
    <message>
        <source>KPhoneView: Incoming Instant Message</source>
        <translation>KPhoneView: Message Instantané Entrant</translation>
    </message>
    <message>
        <source>KPhone</source>
        <translation>KPhone</translation>
    </message>
    <message>
        <source>Subscribe message from uri:</source>
        <translation>Enregistrer le message depuis l'uri:</translation>
    </message>
    <message>
        <source>Do you want to accept and create a contact ?</source>
        <translation>Voulez vous répondre et créer un contact ?</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Répondre</translation>
    </message>
    <message>
        <source>Reject permanently</source>
        <translation>Refus définitif</translation>
    </message>
    <message>
        <source>Reject this time</source>
        <translation>Refus pour cette fois</translation>
    </message>
    <message>
        <source>Incoming call</source>
        <translation>Appel entrant</translation>
    </message>
    <message>
        <source>Set First Identity.</source>
        <translation>Entrer la Première Identité </translation>
    </message>
    <message>
        <source>online</source>
        <translation>en ligne</translation>
    </message>
    <message>
        <source>busy</source>
        <translation>occupé </translation>
    </message>
    <message>
        <source>berightback</source>
        <translation>deretourbientôt</translation>
    </message>
    <message>
        <source>away</source>
        <translation>absent</translation>
    </message>
    <message>
        <source>onthephone</source>
        <translation>autéléphone</translation>
    </message>
    <message>
        <source>outtolunch</source>
        <translation>partimanger</translation>
    </message>
</context>
<context>
    <name>KSipAuthenticationRequest</name>
    <message>
        <source>SipUri = </source>
        <translation>Uri Sip = </translation>
    </message>
    <message>
        <source>Server = </source>
        <translation>Serveur = </translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d'utilisateur:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Mot de passe:</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>bouton ok</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>bouton annuler</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>KSipIdentityEdit</name>
    <message>
        <source>Identity Editor</source>
        <translation>Editeur d'identité </translation>
    </message>
    <message>
        <source>Full Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>User Part of SIP URL:</source>
        <translation>Partie utilisateur de l'URL SIP:</translation>
    </message>
    <message>
        <source>Host Part of SIP URL:</source>
        <translation>Partie hôte de l'URL SIP:</translation>
    </message>
    <message>
        <source>Outbound Proxy (optional):</source>
        <translation>Proxy Sortant (optionnel):</translation>
    </message>
    <message>
        <source>Authentication Username (optional):</source>
        <translation>Login (optionnel):</translation>
    </message>
    <message>
        <source>q-value between 0.0-1.0 (optional):</source>
        <translation>q-value entre 0.0-1.0 (optionnel):</translation>
    </message>
    <message>
        <source>Auto Register</source>
        <translation>Enregistrement Auto</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>S'enregistrer</translation>
    </message>
    <message>
        <source>help button</source>
        <translation>bouton aide</translation>
    </message>
    <message>
        <source>&amp;help...</source>
        <translation>&amp;aide...</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>bouton ok</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>bouton annuler</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <source>Registration : </source>
        <translation>Enregistrement :</translation>
    </message>
    <message>
        <source>Unregister</source>
        <translation>Se désenregistrer</translation>
    </message>
</context>
<context>
    <name>KSipOptions</name>
    <message>
        <source>URI to Request Options For:</source>
        <translation>URI où demander les Options:</translation>
    </message>
    <message>
        <source>Results:</source>
        <translation>Résultats:</translation>
    </message>
    <message>
        <source>Make Query</source>
        <translation>Envoyer Demande</translation>
    </message>
</context>
<context>
    <name>KSipPreferences</name>
    <message>
        <source>Global SIP Preferences</source>
        <translation>Préférences SIP Globales</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Réglages</translation>
    </message>
    <message>
        <source>Hide Via</source>
        <translation>Cacher Via</translation>
    </message>
    <message>
        <source>Don&apos;t Hide</source>
        <translation>Ne pas cacher</translation>
    </message>
    <message>
        <source>Request Next Hop</source>
        <translation type="unfinished">Prochaine correspondance</translation>
    </message>
    <message>
        <source>Request Full Route</source>
        <translation>Chemin complet</translation>
    </message>
    <message>
        <source>Max Forwards</source>
        <translation type="unfinished">Nombre max. de forwards</translation>
    </message>
    <message>
        <source>XML-File for Phone Book:</source>
        <translation>Fichier XML de l'annuaire:</translation>
    </message>
    <message>
        <source>Expire Time of Registration (second):</source>
        <translation>Temps limite pour l'enregistrement (secondes):</translation>
    </message>
    <message>
        <source>Expire Time of Presence Subscription (second):</source>
        <translation type="unfinished">Temps limite pour la souscription (secondes):</translation>
    </message>
    <message>
        <source>Socket Protocol (Kphone restart needed to apply change)</source>
        <translation>Utiliser les Sockets (redémarrer KPhone pour prendre en compte cette modification)</translation>
    </message>
    <message>
        <source>UDP</source>
        <translation>UDP</translation>
    </message>
    <message>
        <source>TCP</source>
        <translation>TCP</translation>
    </message>
    <message>
        <source>Use STUN Server</source>
        <translation>Utiliser un serveur STUN</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Symmetric Signalling</source>
        <translation type="unfinished">Signal Symétrique</translation>
    </message>
    <message>
        <source>Symmetric Media</source>
        <translation type="unfinished">Média Symétrique</translation>
    </message>
    <message>
        <source>STUN Server (address:port):</source>
        <translation>Serveur STUN (adresse:port):</translation>
    </message>
    <message>
        <source>Request Period for STUN Server (second):</source>
        <translation>Période pour serveur STUN (secondes):</translation>
    </message>
    <message>
        <source>Media Min Port:</source>
        <translation>Port min. pour Média:</translation>
    </message>
    <message>
        <source>Media Max Port:</source>
        <translation>Port max. pour Média:</translation>
    </message>
    <message>
        <source>Call Preferences</source>
        <translation>Préférences Appel</translation>
    </message>
    <message>
        <source>Busy Message:</source>
        <translation>Message Occupé:</translation>
    </message>
    <message>
        <source>Call Forwarding</source>
        <translation>Redirection d'Appel</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inactif</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <source>Forward to:</source>
        <translation>Rediriger vers:</translation>
    </message>
    <message>
        <source>Call Forward Message:</source>
        <translation>Message de Redirection:</translation>
    </message>
</context>
<context>
    <name>KSipRegistrations</name>
    <message>
        <source>off</source>
        <translation>déconnecté </translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identité </translation>
    </message>
    <message>
        <source>Restart Kphone to apply identity changes.</source>
        <translation>Redémarrer KPhone pour appliquer les changements d'identité.</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inactif</translation>
    </message>
    <message>
        <source>Trying...</source>
        <translation>Connexion...</translation>
    </message>
    <message>
        <source>Auth Required...</source>
        <translation>Auth. Demandée...</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <source>Unregistering...</source>
        <translation>Désenregistrement...</translation>
    </message>
    <message>
        <source>Reregistering...</source>
        <translation>Ré-enregistrement...</translation>
    </message>
    <message>
        <source>Digest Authentication Request</source>
        <translation>Auth. Digest demandée</translation>
    </message>
    <message>
        <source>Basic Authentication Request</source>
        <translation>Basic Auth. demandée</translation>
    </message>
    <message>
        <source>Proxy Digest Authentication Request</source>
        <translation>Proxy Auth. Digest demandée</translation>
    </message>
    <message>
        <source>Proxy Basic Authentication Request</source>
        <translation>Proxy Basic Auth. demandée</translation>
    </message>
</context>
<context>
    <name>KTestOptions</name>
    <message>
        <source>Address:</source>
        <translation>Adresse:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Message:</translation>
    </message>
    <message>
        <source>Clean</source>
        <translation>Nettoyer</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Fichiers texte (*.txt)</translation>
    </message>
    <message>
        <source>open file dialogChoose a file</source>
        <translation type="unfinished">dialogue d'ouverture de fichier</translation>
    </message>
</context>
<context>
    <name>PhoneBook</name>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Cacher</translation>
    </message>
    <message>
        <source>Permanently rejected contacts</source>
        <translation>Contacts définitivement rejetés</translation>
    </message>
    <message>
        <source>PhoneBook</source>
        <translation>Annuaire</translation>
    </message>
    <message>
        <source>KPhone</source>
        <translation>KPhone</translation>
    </message>
    <message>
        <source>Select first item.</source>
        <translation>Choisir le premier item.</translation>
    </message>
    <message>
        <source>Are You Sure ?</source>
        <translation>Etes vous sûr(e) ?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
</context>
<context>
    <name>PhoneBookAddIdentity</name>
    <message>
        <source>Person:</source>
        <translation>Personne:</translation>
    </message>
    <message>
        <source>Identity:</source>
        <translation>Identité:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Description:</translation>
    </message>
    <message>
        <source>Add Identity to Contacts List</source>
        <translation>Ajouter à la liste de contacts</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>bouton ok</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>bouton annuler</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>PhoneBookEditIdentity</name>
    <message>
        <source>Identity:</source>
        <translation>Identité:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Description:</translation>
    </message>
    <message>
        <source>Add Identity to Contacts List</source>
        <translation>Ajouter à la liste des contacts</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>PhoneBookEditPerson</name>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>PhoneBookParser</name>
    <message>
        <source>Identity</source>
        <translation>Identité </translation>
    </message>
    <message>
        <source>Contact</source>
        <translation>Contact</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Permanently rejected contacts</source>
        <translation>Contacts définitivements rejetés</translation>
    </message>
    <message>
        <source>Call Register</source>
        <translation>Enregistrement</translation>
    </message>
    <message>
        <source>Received calls</source>
        <translation>Appels reçus</translation>
    </message>
    <message>
        <source>Missed calls</source>
        <translation>Appels manqués</translation>
    </message>
    <message>
        <source>PhoneBook</source>
        <translation>Annuaire</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>description</source>
        <translation>description</translation>
    </message>
    <message>
        <source>contact</source>
        <translation>contact</translation>
    </message>
</context>
<context>
    <name>SipCallMember</name>
    <message>
        <source>Response: </source>
        <translation>Réponse: </translation>
    </message>
    <message>
        <source>Connected: </source>
        <translation>Connecté: </translation>
    </message>
    <message>
        <source>Redirected: </source>
        <translation>Redirigé: </translation>
    </message>
    <message>
        <source>Call Failed: </source>
        <translation>Echec Appel:</translation>
    </message>
    <message>
        <source>Disconnecting</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Transfering</source>
        <translation>Transfert</translation>
    </message>
    <message>
        <source>Querying options</source>
        <translation>Demande d'Options</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connecté </translation>
    </message>
    <message>
        <source>Not Acceptable Here</source>
        <translation>Non accepté ici</translation>
    </message>
    <message>
        <source>Rejecting call invitation</source>
        <translation>Refus de l'Invitation</translation>
    </message>
    <message>
        <source>Invitation received</source>
        <translation>Invitation reçue</translation>
    </message>
    <message>
        <source>Session update requested</source>
        <translation>Demande de remise à jour de Session</translation>
    </message>
    <message>
        <source>Remote end disconnected</source>
        <translation>Correspondant deconnecté </translation>
    </message>
    <message>
        <source>Refer</source>
        <translation  type="unfinished">Refer</translation>
    </message>
    <message>
        <source>Request cancelled</source>
        <translation>Demande annulée</translation>
    </message>
</context>
<context>
    <name>SipTransaction</name>
    <message>
        <source>Online</source>
        <translation>En ligne</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Occupé </translation>
    </message>
    <message>
        <source>Be Right Back</source>
        <translation>Bientôt de retour</translation>
    </message>
    <message>
        <source>Away</source>
        <translation>Absent</translation>
    </message>
    <message>
        <source>On The Phone</source>
        <translation>Au Téléphone</translation>
    </message>
    <message>
        <source>Out To Lunch</source>
        <translation>Parti Manger</translation>
    </message>
</context>
<context>
    <name>VideoControl</name>
    <message>
        <source>Video Properties</source>
        <translation>Propriétés Vidéos</translation>
    </message>
    <message>
        <source>Preferred Video Codec</source>
        <translation>Codec Vidéo Préféré </translation>
    </message>
    <message>
        <source>H261</source>
        <translation>H261</translation>
    </message>
    <message>
        <source>H263</source>
        <translation>H263</translation>
    </message>
    <message>
        <source>ok button</source>
        <translation>bouton ok</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>cancel button</source>
        <translation>bouton annuler</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
</TS>
